<!DOCTYPE html>
<html>
  <head>
    <meta charset="UTF-8" />
    <title>On Tap</title>
    <link href="http://fonts.googleapis.com/css?family=PT+Sans:400,700,400italic" rel="stylesheet" type="text/css">
    <link rel="stylesheet" href="/static/mobile.css" type="text/css">
    <meta name="apple-mobile-web-app-capable" content="yes" />
  </head>

  <body>
    <div class="body-container">
      <div class="ontap">On Tap</div>

      {% for tap in taps %}
      <div class="tap" tap_id="{{ tap["tap_id"] }}">
        <div class="name"></div>
        <div class="brewery"></div>
        <div class="brewerydescription"></div>
        <div class="location"></div>
        <div class="style"></div>
        <div class="abv"></div>
        <div class="description"></div>

        <img class="beerimg" />
        <img class="breweryimg" />
      </div>
      {% end %}

      {% for tap in taps %}
      <div class="tap-id" tap_id="{{ tap["tap_id"] }}">{{ tap["tap_id"] }}</div>
      {% end %}
    </div>

    <script type="text/javascript" src="/static/jquery-1.8.2.min.js"></script>
    <script type="text/javascript" src="/static/common.js"></script>
    <script type="text/javascript" src="/static/app.js"></script>
  </body>
</html>
